@@ -1,5 +1,5 @@
 package XML::Grammar::Screenplay::FromProto;
-$XML::Grammar::Screenplay::FromProto::VERSION = '0.28.1';
+$XML::Grammar::Screenplay::FromProto::VERSION = '0.30.0';
 use strict;
 use warnings;
 use autodie;
@@ -156,6 +156,36 @@ sub _handle_elem_of_name_img
 
 }
 
+sub _handle_elem_of_name_q
+{
+    my ( $self, $elem ) = @_;
+
+    my $q_cb = sub {
+        return $self->_output_tag_with_childs(
+            {
+                start => [ "q", ],
+                elem  => $elem,
+            }
+        );
+    };
+
+    return (
+        ( $self->_writer->within_element( $self->_paragraph_tag ) )
+        ? $q_cb->()
+        : do
+        {
+            Carp::confess("<q> element not at toplevel!");
+            $self->_output_tag(
+                {
+                    start => [ "para", ],
+                    in    => $q_cb,
+                }
+            );
+        }
+    );
+
+}
+
 sub _handle_elem_of_name_a
 {
     my ( $self, $elem ) = @_;
@@ -288,7 +318,7 @@ Converts the file $path_to_file to XML and returns it.
 
 =head1 VERSION
 
-version 0.28.1
+version 0.30.0
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
